pub struct SimpleValidator {
pub pub_key: Option<PublicKey>,
pub voting_power: i64,
}Expand description
SimpleValidator is a Validator, which is serialized and hashed in consensus. Address is removed because it’s redundant with the pubkey. Proposer priority is removed because it changes every round.
Fields
pub_key: Option<PublicKey>voting_power: i64Trait Implementations
Sourceimpl Clone for SimpleValidator
impl Clone for SimpleValidator
Sourcefn clone(&self) -> SimpleValidator
fn clone(&self) -> SimpleValidator
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for SimpleValidator
impl Debug for SimpleValidator
Sourceimpl Default for SimpleValidator
impl Default for SimpleValidator
Sourcefn default() -> SimpleValidator
fn default() -> SimpleValidator
Returns the “default value” for a type. Read more
impl Eq for SimpleValidator
Sourceimpl From<SimpleValidator> for SimpleValidator
impl From<SimpleValidator> for SimpleValidator
Sourcefn from(value: SimpleValidator) -> SimpleValidator
fn from(value: SimpleValidator) -> SimpleValidator
Converts to this type from the input type.
Sourceimpl Hash for SimpleValidator
impl Hash for SimpleValidator
Sourceimpl Message for SimpleValidator
impl Message for SimpleValidator
Sourcefn encoded_len(&self) -> usize
fn encoded_len(&self) -> usize
Returns the encoded length of the message without a length delimiter.
Sourcefn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
fn encode(&self, buf: &mut impl BufMut) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message to a buffer. Read more
Sourcefn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message to a newly allocated buffer.
Sourcefn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
fn encode_length_delimited(
&self,
buf: &mut impl BufMut,
) -> Result<(), EncodeError>where
Self: Sized,
Encodes the message with a length-delimiter to a buffer. Read more
Sourcefn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
fn encode_length_delimited_to_vec(&self) -> Vec<u8> ⓘwhere
Self: Sized,
Encodes the message with a length-delimiter to a newly allocated buffer.
Sourcefn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes an instance of the message from a buffer. Read more
Sourcefn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
fn decode_length_delimited(buf: impl Buf) -> Result<Self, DecodeError>where
Self: Default,
Decodes a length-delimited instance of the message from the buffer.
Sourcefn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes an instance of the message from a buffer, and merges it into
self. Read moreSourcefn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
fn merge_length_delimited(&mut self, buf: impl Buf) -> Result<(), DecodeError>where
Self: Sized,
Decodes a length-delimited instance of the message from buffer, and
merges it into
self.Sourceimpl PartialEq for SimpleValidator
impl PartialEq for SimpleValidator
Sourcefn eq(&self, other: &SimpleValidator) -> bool
fn eq(&self, other: &SimpleValidator) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SimpleValidator